`sgqlc.introspection` module
============================

.. automodule:: sgqlc.introspection
    :members:
    :special-members:
    :show-inheritance:

sgqlc.introspection Command Line Options
----------------------------------------

.. argparse::
   :module: sgqlc.introspection.__main__
   :func: get_arg_parse
   :prog: python3 -m sgqlc.introspection
